@@ -24,6 +24,7 @@ from openstack.cluster.v1 import profile_type as _profile_type
 from openstack.cluster.v1 import receiver as _receiver
 from openstack import proxy2
 from openstack import resource2
+from openstack import utils
 
 
 class Proxy(proxy2.BaseProxy):
@@ -275,9 +276,21 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._update(_cluster.Cluster, cluster, **attrs)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use add_nodes_to_cluster instead")
     def cluster_add_nodes(self, cluster, nodes):
         """Add nodes to a cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param nodes: List of nodes to be added to the cluster.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.add_nodes_to_cluster(cluster, nodes)
+
+    def add_nodes_to_cluster(self, cluster, nodes):
+        """Add nodes to a cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param nodes: List of nodes to be added to the cluster.
@@ -287,25 +300,59 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.add_nodes(self.session, nodes)
+        return obj.add_nodes(self._session, nodes)
 
-    def cluster_del_nodes(self, cluster, nodes):
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use remove_nodes_from_cluster instead")
+    def cluster_del_nodes(self, cluster, nodes, **params):
         """Remove nodes from a cluster.
 
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param nodes: List of nodes to be removed from the cluster.
+        :param kwargs \*\*params: Optional query parameters to be sent to
+            restrict the nodes to be returned. Available parameters include:
+
+            * destroy_after_deletion: A boolean value indicating whether the
+                                      deleted nodes to be destroyed right away.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.remove_nodes_from_cluster(cluster, nodes, **params)
+
+    def remove_nodes_from_cluster(self, cluster, nodes, **params):
+        """Remove nodes from a cluster.
+
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param nodes: List of nodes to be removed from the cluster.
+        :param kwargs \*\*params: Optional query parameters to be sent to
+            restrict the nodes to be returned. Available parameters include:
+
+            * destroy_after_deletion: A boolean value indicating whether the
+                                      deleted nodes to be destroyed right away.
         :returns: A dict containing the action initiated by this operation.
         """
         if isinstance(cluster, _cluster.Cluster):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.del_nodes(self.session, nodes)
+        return obj.del_nodes(self._session, nodes, **params)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use replace_nodes_in_cluster instead")
     def cluster_replace_nodes(self, cluster, nodes):
         """Replace the nodes in a cluster with specified nodes.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param nodes: List of nodes to be deleted/added to the cluster.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.replace_nodes_in_cluster(cluster, nodes)
+
+    def replace_nodes_in_cluster(self, cluster, nodes):
+        """Replace the nodes in a cluster with specified nodes.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param nodes: List of nodes to be deleted/added to the cluster.
@@ -315,11 +362,24 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.replace_nodes(self.session, nodes)
+        return obj.replace_nodes(self._session, nodes)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use scale_out_cluster instead")
     def cluster_scale_out(self, cluster, count=None):
         """Inflate the size of a cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param count: Optional parameter specifying the number of nodes to
+            be added.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.scale_out_cluster(cluster, count)
+
+    def scale_out_cluster(self, cluster, count=None):
+        """Inflate the size of a cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param count: Optional parameter specifying the number of nodes to
@@ -330,11 +390,24 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.scale_out(self.session, count)
+        return obj.scale_out(self._session, count)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use scale_in_cluster instead")
     def cluster_scale_in(self, cluster, count=None):
         """Shrink the size of a cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param count: Optional parameter specifying the number of nodes to
+            be removed.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.scale_in_cluster(cluster, count)
+
+    def scale_in_cluster(self, cluster, count=None):
+        """Shrink the size of a cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param count: Optional parameter specifying the number of nodes to
@@ -345,11 +418,24 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.scale_in(self.session, count)
+        return obj.scale_in(self._session, count)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use resize_cluster instead")
     def cluster_resize(self, cluster, **params):
         """Resize of cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param dict \*\*params: A dictionary providing the parameters for the
+            resize action.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.resize_cluster(cluster, **params)
+
+    def resize_cluster(self, cluster, **params):
+        """Resize of cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param dict \*\*params: A dictionary providing the parameters for the
@@ -360,11 +446,25 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.resize(self.session, **params)
+        return obj.resize(self._session, **params)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use attach_policy_to_cluster instead")
     def cluster_attach_policy(self, cluster, policy, **params):
         """Attach a policy to a cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param policy: Either the name or the ID of a policy.
+        :param dict \*\*params: A dictionary containing the properties for the
+            policy to be attached.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.attach_policy_to_cluster(cluster, policy, **params)
+
+    def attach_policy_to_cluster(self, cluster, policy, **params):
+        """Attach a policy to a cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param policy: Either the name or the ID of a policy.
@@ -376,11 +476,23 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.policy_attach(self.session, policy, **params)
+        return obj.policy_attach(self._session, policy, **params)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use detach_policy_from_cluster instead")
     def cluster_detach_policy(self, cluster, policy):
         """Attach a policy to a cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param policy: Either the name or the ID of a policy.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.detach_policy_from_cluster(cluster, policy)
+
+    def detach_policy_from_cluster(self, cluster, policy):
+        """Detach a policy from a cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param policy: Either the name or the ID of a policy.
@@ -390,11 +502,25 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.policy_detach(self.session, policy)
+        return obj.policy_detach(self._session, policy)
 
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use update_cluster_policy instead")
     def cluster_update_policy(self, cluster, policy, **params):
         """Change properties of a policy which is bound to the cluster.
 
+        :param cluster: Either the name or the ID of the cluster, or an
+            instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
+        :param policy: Either the name or the ID of a policy.
+        :param dict \*\*params: A dictionary containing the new properties for
+            the policy.
+        :returns: A dict containing the action initiated by this operation.
+        """
+        return self.update_cluster_policy(cluster, policy, **params)
+
+    def update_cluster_policy(self, cluster, policy, **params):
+        """Change properties of a policy which is bound to the cluster.
+
         :param cluster: Either the name or the ID of the cluster, or an
             instance of :class:`~openstack.cluster.v1.cluster.Cluster`.
         :param policy: Either the name or the ID of a policy.
@@ -406,7 +532,7 @@ class Proxy(proxy2.BaseProxy):
             obj = cluster
         else:
             obj = self._find(_cluster.Cluster, cluster, ignore_missing=False)
-        return obj.policy_update(self.session, policy, **params)
+        return obj.policy_update(self._session, policy, **params)
 
     def collect_cluster_attrs(self, cluster, path):
         """Collect attribute values across a cluster.
@@ -421,30 +547,59 @@ class Proxy(proxy2.BaseProxy):
                           cluster_id=cluster, path=path)
 
     def check_cluster(self, cluster, **params):
-        """check a cluster.
+        """Check a cluster.
 
         :param cluster: The value can be either the ID of a cluster or a
             :class:`~openstack.cluster.v1.cluster.Cluster` instance.
-        :param dict \*\*params: A dictionary providing the parameters for the
+        :param dict params: A dictionary providing the parameters for the
             check action.
 
         :returns: A dictionary containing the action ID.
         """
         obj = self._get_resource(_cluster.Cluster, cluster)
-        return obj.check(self.session, **params)
+        return obj.check(self._session, **params)
 
     def recover_cluster(self, cluster, **params):
-        """recover a node.
+        """recover a cluster.
 
         :param cluster: The value can be either the ID of a cluster or a
             :class:`~openstack.cluster.v1.cluster.Cluster` instance.
-        :param dict \*\*params: A dictionary providing the parameters for the
-            check action.
+        :param dict params: A dictionary providing the parameters for the
+                            recover action.
 
         :returns: A dictionary containing the action ID.
         """
         obj = self._get_resource(_cluster.Cluster, cluster)
-        return obj.recover(self.session, **params)
+        return obj.recover(self._session, **params)
+
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use perform_operation_on_cluster instead")
+    def cluster_operation(self, cluster, operation, **params):
+        """Perform an operation on the specified cluster.
+
+        :param cluster: The value can be either the ID of a cluster or a
+            :class:`~openstack.cluster.v1.cluster.Cluster` instance.
+        :param operation: A string specifying the operation to be performed.
+        :param dict params: A dictionary providing the parameters for the
+                            operation.
+
+        :returns: A dictionary containing the action ID.
+        """
+        return self.perform_operation_on_cluster(cluster, operation, **params)
+
+    def perform_operation_on_cluster(self, cluster, operation, **params):
+        """Perform an operation on the specified cluster.
+
+        :param cluster: The value can be either the ID of a cluster or a
+            :class:`~openstack.cluster.v1.cluster.Cluster` instance.
+        :param operation: A string specifying the operation to be performed.
+        :param dict params: A dictionary providing the parameters for the
+                            operation.
+
+        :returns: A dictionary containing the action ID.
+        """
+        obj = self._get_resource(_cluster.Cluster, cluster)
+        return obj.op(self._session, operation, **params)
 
     def create_node(self, **attrs):
         """Create a new node from attributes.
@@ -473,28 +628,6 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._delete(_node.Node, node, ignore_missing=ignore_missing)
 
-    def check_node(self, node, **params):
-        """check a node.
-
-        :param node: The value can be either the ID of a node or a
-            :class:`~openstack.cluster.v1.node.Node` instance.
-
-        :returns: A dictionary containing the action ID.
-        """
-        obj = self._get_resource(_node.Node, node)
-        return obj.check(self.session, **params)
-
-    def recover_node(self, node, **params):
-        """recover a node.
-
-        :param node: The value can be either the ID of a node or a
-            :class:`~openstack.cluster.v1.node.Node` instance.
-
-        :returns: A dictionary containing the action ID.
-        """
-        obj = self._get_resource(_node.Node, node)
-        return obj.recover(self.session, **params)
-
     def find_node(self, name_or_id, ignore_missing=True):
         """Find a single node.
 
@@ -563,6 +696,60 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._update(_node.Node, node, **attrs)
 
+    def check_node(self, node, **params):
+        """Check the health of the specified node.
+
+        :param node: The value can be either the ID of a node or a
+            :class:`~openstack.cluster.v1.node.Node` instance.
+        :param dict params: A dictionary providing the parametes to the check
+                            action.
+
+        :returns: A dictionary containing the action ID.
+        """
+        obj = self._get_resource(_node.Node, node)
+        return obj.check(self._session, **params)
+
+    def recover_node(self, node, **params):
+        """Recover the specified node into healthy status.
+
+        :param node: The value can be either the ID of a node or a
+            :class:`~openstack.cluster.v1.node.Node` instance.
+        :param dict params: A dict supplying parameters to the recover action.
+
+        :returns: A dictionary containing the action ID.
+        """
+        obj = self._get_resource(_node.Node, node)
+        return obj.recover(self._session, **params)
+
+    @utils.deprecated(deprecated_in="0.9.14", removed_in="1.0",
+                      details="Use perform_operation_on_node instead")
+    def node_operation(self, node, operation, **params):
+        """Perform an operation on the specified node.
+
+        :param cluster: The value can be either the ID of a node or a
+            :class:`~openstack.cluster.v1.node.Node` instance.
+        :param operation: A string specifying the operation to be performed.
+        :param dict params: A dictionary providing the parameters for the
+                            operation.
+
+        :returns: A dictionary containing the action ID.
+        """
+        return self.perform_operation_on_node(node, operation, **params)
+
+    def perform_operation_on_node(self, node, operation, **params):
+        """Perform an operation on the specified node.
+
+        :param cluster: The value can be either the ID of a node or a
+            :class:`~openstack.cluster.v1.node.Node` instance.
+        :param operation: A string specifying the operation to be performed.
+        :param dict params: A dictionary providing the parameters for the
+                            operation.
+
+        :returns: A dictionary containing the action ID.
+        """
+        obj = self._get_resource(_node.Node, node)
+        return obj.op(self._session, operation, **params)
+
     def create_policy(self, **attrs):
         """Create a new policy from attributes.
 
@@ -674,6 +861,7 @@ class Proxy(proxy2.BaseProxy):
             :class:`~openstack.cluster.v1.cluster.Cluster` instance.
         :param kwargs \*\*query: Optional query parameters to be sent to
             restrict the policies to be returned. Available parameters include:
+
             * enabled: A boolean value indicating whether the policy is
                        enabled on the cluster.
         :returns: A generator of cluster-policy binding instances.
