@@ -64,23 +64,35 @@ class Agent(resource.Resource):
     #: The messaging queue topic the network agent subscribes to.
     topic = resource.Body('topic')
 
-    def add_agent_to_network(self, session, **body):
+    def add_agent_to_network(self, session, network_id):
+        body = {'network_id': network_id}
         url = utils.urljoin(self.base_path, self.id, 'dhcp-networks')
         resp = session.post(url, endpoint_filter=self.service, json=body)
         return resp.json()
 
-    def remove_agent_from_network(self, session, **body):
-        network_id = body.get('network_id')
+    def remove_agent_from_network(self, session, network_id):
+        body = {'network_id': network_id}
         url = utils.urljoin(self.base_path, self.id, 'dhcp-networks',
                             network_id)
         session.delete(url, endpoint_filter=self.service, json=body)
 
+    def add_router_to_agent(self, session, router):
+        body = {'router_id': router}
+        url = utils.urljoin(self.base_path, self.id, 'l3-routers')
+        resp = session.post(url, endpoint_filter=self.service, json=body)
+        return resp.json()
 
-class DHCPAgentHostingNetwork(resource.Resource):
-    resource_key = 'network'
-    resources_key = 'networks'
-    base_path = '/agents/%(agent_id)s/dhcp-networks'
-    resource_name = 'dhcp-network'
+    def remove_router_from_agent(self, session, router):
+        body = {'router_id': router}
+        url = utils.urljoin(self.base_path, self.id, 'l3-routers', router)
+        session.delete(url, endpoint_filter=self.service, json=body)
+
+
+class NetworkHostingDHCPAgent(Agent):
+    resource_key = 'agent'
+    resources_key = 'agents'
+    resource_name = 'dhcp-agent'
+    base_path = '/networks/%(network_id)s/dhcp-agents'
     service = network_service.NetworkService()
 
     # capabilities
@@ -90,4 +102,21 @@ class DHCPAgentHostingNetwork(resource.Resource):
     allow_delete = False
     allow_list = True
 
+    # NOTE: Doesn't support query yet.
+
+
+class RouterL3Agent(Agent):
+    resource_key = 'agent'
+    resources_key = 'agents'
+    base_path = '/routers/%(router_id)s/l3-agents'
+    resource_name = 'l3-agent'
+    service = network_service.NetworkService()
+
+    # capabilities
+    allow_create = False
+    allow_retrieve = True
+    allow_update = False
+    allow_delete = False
+    allow_list = True
+
     # NOTE: No query parameter is supported
